@@ -165,7 +165,7 @@ class PyCTPP2TemplateRenderer(object):
         loc = None
         if 'request' in system:
             loc = get_locale_name(system['request'])
-            value['__LOCALE__'] = loc
+            value['LOCALE_'] = loc
 
         return self.template.render(value, locale=loc)
 
